@@ -195,6 +195,26 @@ class DripBase(object):
         return walked_range
 
     def apply_queryset_rules(self, qs: str) -> str:
+        return (
+                self.apply_and_queryset_rules(qs) |
+                self.apply_or_queryset_rules(qs)
+               )
+
+    def apply_or_queryset_rules(self, qs: str) -> str:
+        rules = []
+        rule_set = self.drip_model.queryset_rules.filter(rule_type='or')
+        for rule in rule_set:
+            kwargs = rule.filter_kwargs(now=self.now)
+            query_or = Q(**kwargs)
+            rules.append(query_or)
+
+        query = rules.pop() if rules else None
+        for rule in rules:
+            query |= rule
+        qs = qs.filter(query) if query else qs.none()
+        return qs
+
+    def apply_and_queryset_rules(self, qs: str) -> str:
         """First collect all filter/exclude kwargs and apply any annotations.
         Then apply all filters at once, and all excludes at once.
 
@@ -207,19 +227,21 @@ class DripBase(object):
             'filter': [],
             'exclude': [],
         }
-
-        for rule in self.drip_model.queryset_rules.all():
+        rules = []
+        for rule in self.drip_model.queryset_rules.filter(rule_type='and'):
+            rules.append(rule)
 
             clause = clauses.get(rule.method_type, clauses['filter'])
 
-            kwargs = rule.filter_kwargs(qs, now=self.now)
+            kwargs = rule.filter_kwargs(now=self.now)
             clause.append(Q(**kwargs))
 
             qs = rule.apply_any_annotation(qs)
 
         if clauses['exclude']:
             qs = qs.exclude(functools.reduce(operator.or_, clauses['exclude']))
-        qs = qs.filter(*clauses['filter'])
+
+        qs = qs.filter(*clauses['filter']) if len(rules) > 0 else qs.none()
 
         return qs
 
